==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Submit_News/language/lang-turkish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PRINTER","Yazdrlabilir Sayfa");
define("_FRIEND","Bu Haberi Arkadana Gnder");
define("_YOURNAME","sminiz");
define("_OK","Tamam!");
define("_ALLOWEDHTML","zin Verilen HTML:");
define("_EXTRANS","HTML tag'leri metne");
define("_HTMLFORMATED","HTML Biimli");
define("_PLAINTEXT","Metin Biimli");
define("_ARTICLES","Haber");
define("_SUBMITNEWS","Haber Ekle");
define("_SUBMITADVICE","Ltfen haberinizi aadaki forma girin ve tekrar kontrol edin.<br>Tm haberlerin postalanmayacan bilmelisiniz.<br>neriniz kontrol edilip yeniden dzenlenebilir.");
define("_SUBTITLE","Balk");
define("_BEDESCRIPTIVE","Aklayc ve basit olun");
define("_BADTITLES","kt balklar= 'Buna bakn!' veya 'Bir Haber'");
define("_HTMLISFINE","HTML kullanabilirsiniz fakat doru yazdnzdan emin olun!");
define("_AREYOUSURE","Bir URL eklediniz mi? Yazm hatalarn kontrol ettiniz mi?");
define("_SUBPREVIEW","Gndermeden nce nizleme yapmalsnz");
define("_SELECTTOPIC","Konu Sein");
define("_NEWSUBPREVIEW","Haber Ekle nizleme");
define("_STORYLOOK","Haberiniz bu ekilde grntlenecek:");
define("_CHECKSTORY","Ltfen gndermeden nce metni ve balantlar kontrol edin!");
define("_THANKSSUB","neriniz iin teekkrler!");
define("_SUBSENT","Haberiniz alnd...");
define("_SUBTEXT","nerinizi birka saat iinde inceleyecek, ve uygun grlrse yaynlayacaz.");
define("_WEHAVESUB","u an");
define("_WAITING","bekleyen neri bulunuyor.");
define("_PREVIEW","nizleme");
define("_NEWUSER","Yeni Kullanc");
define("_USCORE","Puan");
define("_DATE","Tarih");
define("_STORYTEXT","Haber Metni");
define("_EXTENDEDTEXT","Geni Metin");
define("_LANGUAGE","Dil");
define("_JANUARY","Ocak");
define("_FEBRUARY","ubat");
define("_MARCH","Mart");
define("_APRIL","Nisan");
define("_MAY","Mays");
define("_JUNE","Haziran");
define("_JULY","Temmuz");
define("_AUGUST","Austos");
define("_SEPTEMBER","Eyll");
define("_OCTOBER","Ekim");
define("_NOVEMBER","Kasm");
define("_DECEMBER","Aralk");
define("_SELECTMONTH2VIEW","Ltfen grntlemek istediiniz ay sein:");
define("_SHOWALLSTORIES","TM Haberleri Gster");
define("_STORIESARCHIVE","Haber Arivi");
define("_ACTIONS","Hareketler");
define("_ARCHIVESINDEX","Haber Arivi ndeksi");
define("_ALLSTORIESARCH","Tm Haberler");
define("_NEXTPAGE","Sonraki Sayfa");
define("_PREVIOUSPAGE","nceki Sayfa");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Submit_News/language/lang-turkish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PRINTER","Yazdrlabilir Sayfa");
define("_FRIEND","Bu Haberi Arkadana Gnder");
define("_YOURNAME","sminiz");
define("_OK","Tamam!");
define("_ALLOWEDHTML","zin Verilen HTML:");
define("_EXTRANS","HTML tag'leri metne");
define("_HTMLFORMATED","HTML Biimli");
define("_PLAINTEXT","Metin Biimli");
define("_ARTICLES","Haber");
define("_SUBMITNEWS","Haber Ekle");
define("_SUBMITADVICE","Ltfen haberinizi aadaki forma girin ve tekrar kontrol edin.<br>Tm haberlerin postalanmayacan bilmelisiniz.<br>neriniz kontrol edilip yeniden dzenlenebilir.");
define("_SUBTITLE","Balk");
define("_BEDESCRIPTIVE","Aklayc ve basit olun");
define("_BADTITLES","kt balklar= 'Buna bakn!' veya 'Bir Haber'");
define("_HTMLISFINE","HTML kullanabilirsiniz fakat doru yazdnzdan emin olun!");
define("_AREYOUSURE","Bir URL eklediniz mi? Yazm hatalarn kontrol ettiniz mi?");
define("_SUBPREVIEW","Gndermeden nce nizleme yapmalsnz");
define("_SELECTTOPIC","Konu Sein");
define("_NEWSUBPREVIEW","Haber Ekle nizleme");
define("_STORYLOOK","Haberiniz bu ekilde grntlenecek:");
define("_CHECKSTORY","Ltfen gndermeden nce metni ve balantlar kontrol edin!");
define("_THANKSSUB","neriniz iin teekkrler!");
define("_SUBSENT","Haberiniz alnd...");
define("_SUBTEXT","nerinizi birka saat iinde inceleyecek, ve uygun grlrse yaynlayacaz.");
define("_WEHAVESUB","u an");
define("_WAITING","bekleyen neri bulunuyor.");
define("_PREVIEW","nizleme");
define("_NEWUSER","Yeni Kullanc");
define("_USCORE","Puan");
define("_DATE","Tarih");
define("_STORYTEXT","Haber Metni");
define("_EXTENDEDTEXT","Geni Metin");
define("_LANGUAGE","Dil");

define("_SELECTMONTH2VIEW","Ltfen grntlemek istediiniz ay sein:");
define("_SHOWALLSTORIES","TM Haberleri Gster");
define("_STORIESARCHIVE","Haber Arivi");
define("_ACTIONS","Hareketler");
define("_ARCHIVESINDEX","Haber Arivi ndeksi");
define("_ALLSTORIESARCH","Tm Haberler");
define("_NEXTPAGE","Sonraki Sayfa");
define("_PREVIOUSPAGE","nceki Sayfa");

?>
